==> haskell-distributive-0.6.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: distributive
version: 0.6.1
id: distributive-0.6.1-KtvnI7rAte78vJoTCqsT1w
key: distributive-0.6.1-KtvnI7rAte78vJoTCqsT1w
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/distributive/
synopsis: Distributive functors -- Dual to Traversable
description:
    Distributive functors -- Dual to @Traversable@
category: Data Structures
abi: e2d1f1a883360f582c0672a71ae285f1
exposed: True
exposed-modules:
    Data.Distributive Data.Distributive.Generic
import-dirs: /usr/lib/ghc-8.6.5/site-local/distributive-0.6.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/distributive-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/distributive-0.6.1
hs-libraries: HSdistributive-0.6.1-KtvnI7rAte78vJoTCqsT1w
depends:
    base-4.12.0.0 base-orphans-0.8.1-HeyTAcy4PKhDcGhjvJwDzq
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-distributive/html/distributive.haddock
haddock-html: /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-distributive-0.6-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: distributive
version: 0.6
id: distributive-0.6-9NCAlubkmNk4BRxn0siLZI
key: distributive-0.6-9NCAlubkmNk4BRxn0siLZI
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/distributive/
synopsis: Distributive functors -- Dual to Traversable
description:
    Distributive functors -- Dual to @Traversable@
category: Data Structures
abi: a558f75145672234ae67772cdea15ecf
exposed: True
exposed-modules:
    Data.Distributive Data.Distributive.Generic
import-dirs: /usr/lib/ghc-8.6.4/site-local/distributive-0.6
library-dirs: /usr/lib/ghc-8.6.4/site-local/distributive-0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/distributive-0.6
hs-libraries: HSdistributive-0.6-9NCAlubkmNk4BRxn0siLZI
depends:
    base-4.12.0.0 base-orphans-0.8-7pByK7w1VGecEyVBPbOH
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-distributive/html/distributive.haddock
haddock-html: /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
